package com.aleax.voip;

/**
 * Allows classes to receive notifications when Peer-related events occur.
 *  
 * @author Yiannis Paschalidis
 * @see {@link Peers#addListener(PeerListener)}.
 */
public interface PeerListener
{
   /**
    * Called when a Peer connects.
    * 
    * @param peer the Peer who has just connected.
    */
   void peerFound(Peer peer);
   
   
   /**
    * Called when a Peer connection drops out.
    * 
    * @param peer the Peer who has just lost their connection.
    */
   void peerLost(Peer peer);
   
   /**
    * Called when a Peer sends a text message.
    * 
    * @param peer the Peer who sent the message.
    * @param message the message text.
    */
   void peerMessage(Peer peer, String message);
   
   /**
    * Called when the Peer VOIP call state changes.
    * 
    * @param peer the Peer whose calls state has changed.
    * @param fromState the previous call state.
    */
   void peerCallStatusChanged(Peer peer, Peer.CallState fromState);
}
