package com.aleax.voip.ui.settings;

import java.awt.GridBagConstraints;
import java.util.List;

import javax.swing.JLabel;
import javax.swing.JTextField;

import com.aleax.voip.ui.AppConfig;
import com.aleax.voip.util.LengthLimitedTextField;
import com.aleax.voip.util.Util;
import com.aleax.voip.util.ValidationError;

/**
 * General application settings panel.
 * 
 * @author Yiannis Paschalidis
 */
public class GeneralSettingsPanel extends AbstractSettingsPanel
{
   /** The user's nickname. */
   private final JTextField nickName = new LengthLimitedTextField(30);
   
   /**
    * Creates a GeneralSettingsPanel.
    */
   public GeneralSettingsPanel()
   {
      add(new JLabel("Nickname: "), 0, 0, GridBagConstraints.EAST);
      add(nickName, 1, 0);
   }
   
   /** {@inheritDoc} */
   @Override
   public void doValidate(final List<ValidationError> errors)
   {
      String text = nickName.getText().trim();
      
      if (Util.empty(text))
      {
         errors.add(new ValidationError("Nickname is required", nickName));
      }      
      else
      {
         for (int i = text.length() - 1 ; i >= 0 ; i--)
         {
            char c = text.charAt(i);
            
            if (!Character.isLetterOrDigit(c) && c != ' ')
            {
               errors.add(new ValidationError("Nickname can only contain alphanumeric characters", nickName));
            }
         }
      }
   }

   /** {@inheritDoc} */
   @Override
   public void reset()
   {
      nickName.setText(AppConfig.getNickname().trim());
   }

   /** {@inheritDoc} */
   @Override
   public void save()
   {
      AppConfig.setNickname(nickName.getText().trim());
   }
}
