package com.aleax.voip.ui.settings.audio;

/**
 * Encapsulates a sample bit size.
 * @author Yiannis Paschalidis
 */
public final class BitSizeOption implements Comparable<BitSizeOption>
{
   /** The number of bits per sample. */
   private final int bits;
   
   /** The description of this option. */
   private final String desc;

   /** 
    * Creates a BitSizeOption.
    * @param bits the number of bits per sample. 
    */
   public BitSizeOption(final int bits)
   {
      this.bits = bits;
      this.desc = bits + "-bit";
   }

   /** {@inheritDoc} */
   @Override
   public boolean equals(final Object obj)
   {
      return obj instanceof BitSizeOption && ((BitSizeOption) obj).getBits() == this.getBits();
   }

   /** {@inheritDoc} */
   @Override
   public int hashCode()
   {
      return getBits();
   }

   /** {@inheritDoc} */
   @Override
   public int compareTo(final BitSizeOption other)
   {
      return getBits() - other.getBits();
   }
   
   /** {@inheritDoc} */
   @Override
   public String toString()
   {
      return desc;
   }

   /**
    * @return the number of bits per sample.
    */
   public int getBits()
   {
      return bits;
   }
}
