package com.aleax.voip.ui.settings.audio;

/**
 * Encapsulates the number of channels.
 * @author Yiannis Paschalidis
 */
public final class ChannelOption implements Comparable<ChannelOption> 
{
   /** The number of channels. */
   private final int channels;
   
   /** The textual description of this option. */
   private final String desc;
   
   /**
    * Creates a ChannelOption.
    * @param channels the number of channels.
    */
   public ChannelOption(final int channels)
   {
      this.channels = channels;
      
      switch (channels)
      {
         case 1:
            desc = "Mono";
            break;
            
         case 2:
            desc = "Stereo";
            break;
            
         default:
            desc = channels + " channels";
            break;
      }
   }
   
   /** {@inheritDoc} */
   @Override
   public boolean equals(final Object obj)
   {
      return obj instanceof ChannelOption && ((ChannelOption) obj).getChannels() == this.getChannels();
   }
   
   /** {@inheritDoc} */
   @Override
   public int hashCode()
   {
      return getChannels();
   }
   
   /** {@inheritDoc} */
   @Override
   public int compareTo(final ChannelOption other)
   {
      return getChannels() - other.getChannels();
   }
   
   /** {@inheritDoc} */
   @Override
   public String toString()
   {
      return desc;
   }

   /**
    * @return the channels
    */
   public int getChannels()
   {
      return channels;
   }
}
