package com.aleax.voip.ui.settings.audio;

/**
 * Encapsulates a sample rate.
 * @author Yiannis Paschalidis
 */
public final class SampleRateOption implements Comparable<SampleRateOption>
{
   /** The textual description of this sample rate. */
   private final String desc;
   
   /** The sample rate, in Hz. */
   private final int rate;

   /**
    * Creates a SampleRateOption.
    * @param rate the sample Rate, in Hz.
    */
   public SampleRateOption(final int rate)
   {
      if (rate < 0)
      {
         throw new IllegalArgumentException("Invalid sample rate: " + rate);
      }
      
      this.rate = rate;
      this.desc = (rate / 1000.0) + " KHz";
   }

   /** {@inheritDoc} */
   @Override
   public String toString()
   {
      return desc;
   }

   /** {@inheritDoc} */
   @Override
   public boolean equals(final Object obj)
   {
      return obj instanceof SampleRateOption && ((SampleRateOption) obj).getRate() == getRate();
   }

   /** {@inheritDoc} */
   @Override
   public int hashCode()
   {
      return getRate();
   }

   /** {@inheritDoc} */
   @Override
   public int compareTo(final SampleRateOption other)
   {
      return getRate() - other.getRate();
   }

   /**
    * @return the rate
    */
   public int getRate()
   {
      return rate;
   }
}
