package com.aleax.voip.util;

import java.io.UnsupportedEncodingException;
import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;

import sunlabs.brazil.util.Base64;

/**
 * Encryption/decryption utils.
 * 
 * @author Yiannis Paschalidis
 */
public final class EncryptionUtil
{
   /** Prevent instantiation of this utility class. */
   private EncryptionUtil()
   {
   }

   public static byte[] decryptAES(final byte[] encryptedData, final String key) throws Exception
   {
      SecretKeySpec secret = new SecretKeySpec(getKeyBytes(key, 16), "AES");
      Cipher cipher = Cipher.getInstance("AES/ECB/NoPadding");
      cipher.init(Cipher.DECRYPT_MODE, secret);
      return cipher.doFinal(encryptedData);
   }

   public static byte[] encryptAES(final byte[] data, final String key) throws Exception
   {
      SecretKeySpec secret = new SecretKeySpec(getKeyBytes(key, 16), "AES");
      Cipher cipher = Cipher.getInstance("AES/ECB/NoPadding");
      cipher.init(Cipher.ENCRYPT_MODE, secret);
      return cipher.doFinal(data);
   }
   
   public static String encryptDES(final String message, final String key) throws Exception
   {
      SecretKeySpec secret = new SecretKeySpec(getKeyBytes(key, 8), "DES");
      Cipher ecipher = Cipher.getInstance("DES");
      ecipher.init(Cipher.ENCRYPT_MODE, secret);

      byte[] utf8 = message.getBytes("UTF-8");
      byte[] enc = ecipher.doFinal(utf8);

      return Base64.encode(enc);
   }

   public static String decryptDES(final String encryptedMessage, final String key) throws Exception
   {
      SecretKeySpec secret = new SecretKeySpec(getKeyBytes(key, 8), "DES");
      Cipher dcipher = Cipher.getInstance("DES");
      dcipher.init(Cipher.DECRYPT_MODE, secret);
      
      byte[] dec = Base64.decode(encryptedMessage);
      
      byte[] utf8 = dcipher.doFinal(dec);
      
      return new String(utf8, "UTF-8");
   }
   
   private static byte[] getKeyBytes(final String key, final int byteLength)
   {
      try
      {
         byte[] bytes = key.getBytes("UTF-8");
         final int len = bytes.length;
         
         if (len == byteLength)
         {
            return bytes;
         }
         else if (len > byteLength)
         {
            byte[] result = new byte[byteLength];
            System.arraycopy(bytes, 0, result, 0, byteLength);
            return result;
         }
         else
         {
            byte[] result = new byte[byteLength];
            System.arraycopy(bytes, 0, result, 0, len);
            
            for (int i = len ; i < byteLength ; i++)
            {
               bytes[i] = (byte) (bytes[i - 1] + i);
            }
            
            return result;
         }
      }
      catch (UnsupportedEncodingException e)
      {
         // UTF-8 is always supported
         return null;
      }
   }   
}
