package com.aleax.voip.util;

import java.io.IOException;
import java.io.InputStream;
import java.util.logging.ConsoleHandler;
import java.util.logging.Level;
import java.util.logging.LogManager;
import java.util.logging.LogRecord;
import java.util.logging.Logger;
import java.util.logging.SimpleFormatter;
import java.util.logging.StreamHandler;

/**
 * Simple log utility methods. The VOIP app uses java.util.logging, 
 * with the configuration stored internally in the JAR file.
 * 
 * @author Yiannis Paschalidis.
 */
public final class LogUtil
{
   static
   {
      try (InputStream configFile = LogUtil.class.getResourceAsStream("/logging.properties")) 
      {
         LogManager.getLogManager().readConfiguration(configFile);
      }
      catch (IOException ex)
      {
         System.out.println("WARNING: Could not open configuration file\n" 
                          + "WARNING: Logging not configured (console output only)");
      }
   }
   
   /** Prevent instantiation of this utility class. */
   private LogUtil()
   {
   }

   /**
    * Obtains a logger for a class.
    * @param clazz the class to get the logger for.
    * @return the logger for the given class.
    */
   public static Logger get(final Class<?> clazz)
   {
      return Logger.getLogger(clazz.getName());
   }
   
   /**
    * Stream handler implementation which logs to stdout &amp; stderr.
    */
   public static final class SystemOutConsoleHandler extends StreamHandler
   {
      /** Backing handler. */
      private final ConsoleHandler stderrHandler = new ConsoleHandler();

      /** Creates a SystemOutConsoleHandler. */
      public SystemOutConsoleHandler()
      {
         super(System.out, new SimpleFormatter());
      }

      /** {@inheritDoc} */
      @Override
      public void publish(final LogRecord record)
      {
         if (record.getLevel().intValue() <= Level.INFO.intValue())
         {
            super.publish(record);
            super.flush();
         }
         else
         {
            stderrHandler.publish(record);
            stderrHandler.flush();
         }
      }
   }
}
