package com.aleax.voip.util;

/**
 * ValidationError - encapsulates a validation error.
 *
 * @author Yiannis Paschalidis
 * @version 1.0 11/03/2007
 */
public final class ValidationError
{
   /** The description of the error. */
   private final String text;
   
   /** The field which is in error. */
   private final Object field;

   /**
    * Creates a validation error which does not relate to a specific field.
    * @param text the error text.
    */
   public ValidationError(final String text)
   {
      this(text, null);
   }
   
   /**
    * Creates a validation error.
    * 
    * @param text the error text.
    * @param field the field which is in error.
    */
   public ValidationError(final String text, final Object field)
   {
      this.text = text;
      this.field = field;   
   }

   /** @return the field which is in error. */
   public Object getField()
   {
      return field;
   }

   /** @return the description of the error. */
   public String getText()
   {
      return text;
   }
}

